"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.plugin = void 0;
const graphql_codegen_hasura_shared_1 = require("graphql-codegen-hasura-shared");
const plugin = (schema, documents, config) => {
    // Set config defaults
    if (config.reactApolloVersion && config.reactApolloVersion !== 3) {
        throw new Error("Currently this codegen tool is only compatible with Apollo Client V3");
    }
    const contentManager = new graphql_codegen_hasura_shared_1.ContentManager();
    graphql_codegen_hasura_shared_1.injectGlobalHelperCodePre({
        contentManager,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath,
        withUpdates: config.withUpdates,
    });
    // get typemap from schema
    const typeMap = schema.getTypeMap();
    // find fragment documents
    const documentFragments = documents.flatMap((documentItem) => {
        return documentItem.document.definitions.filter((definition) => definition.kind === "FragmentDefinition");
    });
    // iterate and generate
    documentFragments.map((fragmentDefinition) => {
        injectEntitySharedTypeScriptPre(fragmentDefinition, typeMap, contentManager, config);
        config.withClientAndCacheHelpers && injectClientAndCacheTypeScript(fragmentDefinition, typeMap, contentManager, config);
        config.withQueries && injectEntityQueryTypeScript(fragmentDefinition, typeMap, contentManager, config);
        config.withSubscriptions && injectEntitySubscriptionTypeScript(fragmentDefinition, typeMap, contentManager, config);
        config.withInserts && injectEntityInsertMutationTypeScript(fragmentDefinition, typeMap, contentManager, config);
        config.withUpdates && injectEntityUpdateMutationTypeScript(fragmentDefinition, typeMap, contentManager, config);
        config.withDeletes && injectEntityDeleteMutationTypeScript(fragmentDefinition, typeMap, contentManager, config);
        injectEntitySharedTypeScriptPost(fragmentDefinition, typeMap, contentManager, config);
    });
    graphql_codegen_hasura_shared_1.injectGlobalHelperCodePost({
        contentManager,
        fragmentDefinitionNodes: documentFragments,
        schemaTypeMap: typeMap,
        trimString: config.trimString,
        withClientAndCacheHelpers: config.withClientAndCacheHelpers,
        withQueries: config.withQueries,
        withSubscriptions: config.withSubscriptions,
        withInserts: config.withInserts,
        withUpdates: config.withUpdates,
        withDeletes: config.withDeletes,
    });
    return {
        prepend: contentManager.generateImportArray(),
        content: contentManager.createContentString(),
    };
};
exports.plugin = plugin;
// --------------------------------------
//
function injectEntitySharedTypeScriptPre(fragmentDefinitionNode, schemaTypeMap, contentManager, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const entityNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(entityNamedType);
    graphql_codegen_hasura_shared_1.injectSharedHelpersPre({
        contentManager,
        entityNamedType,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath,
    });
}
// --------------------------------------
//
function injectEntitySharedTypeScriptPost(fragmentDefinitionNode, schemaTypeMap, contentManager, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const entityNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(entityNamedType);
    graphql_codegen_hasura_shared_1.injectSharedHelpersPost({
        contentManager,
        entityNamedType,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath,
        withClientAndCacheHelpers: config.withClientAndCacheHelpers,
        withQueries: config.withQueries,
        withSubscriptions: config.withSubscriptions,
        withUpdates: config.withUpdates,
        withInserts: config.withInserts,
        withDeletes: config.withDeletes,
    });
}
// --------------------------------------
//
function injectClientAndCacheTypeScript(fragmentDefinitionNode, schemaTypeMap, contentManager, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const entityNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(entityNamedType);
    graphql_codegen_hasura_shared_1.injectCacheHelpers({
        contentManager,
        entityNamedType,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath,
    });
}
// --------------------------------------
//
function injectEntityQueryTypeScript(fragmentDefinitionNode, schemaTypeMap, contentManager, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const entityNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(entityNamedType);
    graphql_codegen_hasura_shared_1.injectQueryHelpers({
        contentManager,
        entityNamedType,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath,
    });
}
// --------------------------------------
//
function injectEntitySubscriptionTypeScript(fragmentDefinitionNode, schemaTypeMap, contentManager, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const entityNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(entityNamedType);
    graphql_codegen_hasura_shared_1.injectSubscriptionHelpers({
        contentManager,
        entityNamedType,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath,
    });
}
// --------------------------------------
//
function injectEntityInsertMutationTypeScript(fragmentDefinitionNode, schemaTypeMap, contentManager, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const entityNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(entityNamedType);
    if (!relatedTablePrimaryKeyIdField)
        return;
    graphql_codegen_hasura_shared_1.injectInsertHelpers({
        contentManager,
        entityNamedType,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath,
    });
}
// --------------------------------------
//
function injectEntityUpdateMutationTypeScript(fragmentDefinitionNode, schemaTypeMap, contentManager, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const entityNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(entityNamedType);
    if (!relatedTablePrimaryKeyIdField)
        return;
    graphql_codegen_hasura_shared_1.injectUpdateHelpers({
        contentManager,
        entityNamedType,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath,
    });
}
// --------------------------------------
//
function injectEntityDeleteMutationTypeScript(fragmentDefinitionNode, schemaTypeMap, contentManager, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const entityNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(entityNamedType);
    graphql_codegen_hasura_shared_1.injectDeleteHelpers({
        contentManager,
        entityNamedType,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath,
    });
}
// --------------------------------------
//
//# sourceMappingURL=index.js.map